@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct OauthAuthorizations {
-    client: Client,
+    pub client: Client,
 }
 
 impl OauthAuthorizations {
@@ -35,24 +35,18 @@ impl OauthAuthorizations {
         page: i64,
         client_id: &str,
     ) -> Result<Vec<crate::types::ApplicationGrant>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !client_id.is_empty() {
-            query_args.push(format!("client_id={}", client_id));
+            query_args.push(("client_id".to_string(), client_id.to_string()));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/applications/grants?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/applications/grants?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -74,18 +68,12 @@ impl OauthAuthorizations {
         &self,
         client_id: &str,
     ) -> Result<Vec<crate::types::ApplicationGrant>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !client_id.is_empty() {
-            query_args.push(format!("client_id={}", client_id));
+            query_args.push(("client_id".to_string(), client_id.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/applications/grants?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/applications/grants?{}", query_);
 
         self.client.get_all_pages(&url, None).await
     }
@@ -157,24 +145,18 @@ impl OauthAuthorizations {
         page: i64,
         client_id: &str,
     ) -> Result<Vec<crate::types::Authorization>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !client_id.is_empty() {
-            query_args.push(format!("client_id={}", client_id));
+            query_args.push(("client_id".to_string(), client_id.to_string()));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/authorizations?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/authorizations?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -194,18 +176,12 @@ impl OauthAuthorizations {
         &self,
         client_id: &str,
     ) -> Result<Vec<crate::types::Authorization>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !client_id.is_empty() {
-            query_args.push(format!("client_id={}", client_id));
+            query_args.push(("client_id".to_string(), client_id.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/authorizations?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/authorizations?{}", query_);
 
         self.client.get_all_pages(&url, None).await
     }
@@ -235,10 +211,7 @@ impl OauthAuthorizations {
     ) -> Result<crate::types::Authorization> {
         let url = "/authorizations".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -274,10 +247,7 @@ impl OauthAuthorizations {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -314,10 +284,7 @@ impl OauthAuthorizations {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -396,10 +363,7 @@ impl OauthAuthorizations {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
