@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Pulls {
-    client: Client,
+    pub client: Client,
 }
 
 impl Pulls {
@@ -47,34 +47,34 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::PullRequestSimple>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !base.is_empty() {
-            query_args.push(format!("base={}", base));
+            query_args.push(("base".to_string(), base.to_string()));
+        }
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
         }
-        query_args.push(format!("direction={}", direction));
         if !head.is_empty() {
-            query_args.push(format!("head={}", head));
+            query_args.push(("head".to_string(), head.to_string()));
         }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -101,28 +101,28 @@ impl Pulls {
         sort: crate::types::PullsListSort,
         direction: crate::types::Order,
     ) -> Result<Vec<crate::types::PullRequestSimple>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !base.is_empty() {
-            query_args.push(format!("base={}", base));
+            query_args.push(("base".to_string(), base.to_string()));
+        }
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
         }
-        query_args.push(format!("direction={}", direction));
         if !head.is_empty() {
-            query_args.push(format!("head={}", head));
+            query_args.push(("head".to_string(), head.to_string()));
         }
-        query_args.push(format!("sort={}", sort));
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -161,10 +161,7 @@ impl Pulls {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -199,30 +196,28 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::PullRequestReviewComment>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/comments?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -247,24 +242,22 @@ impl Pulls {
         direction: crate::types::Order,
         since: Option<chrono::DateTime<chrono::Utc>>,
     ) -> Result<Vec<crate::types::PullRequestReviewComment>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/comments?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -362,10 +355,7 @@ impl Pulls {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -446,10 +436,7 @@ impl Pulls {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -486,31 +473,29 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::PullRequestReviewComment>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/{}/comments?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&pull_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -536,25 +521,23 @@ impl Pulls {
         direction: crate::types::Order,
         since: Option<chrono::DateTime<chrono::Utc>>,
     ) -> Result<Vec<crate::types::PullRequestReviewComment>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("direction={}", direction));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !direction.to_string().is_empty() {
+            query_args.push(("direction".to_string(), direction.to_string()));
+        }
         if let Some(date) = since {
-            query_args.push(format!("since={}", &date.to_rfc3339()));
+            query_args.push(("since".to_string(), date.to_rfc3339()));
         }
-        query_args.push(format!("sort={}", sort));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !sort.to_string().is_empty() {
+            query_args.push(("sort".to_string(), sort.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/{}/comments?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&pull_number.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -597,10 +580,7 @@ impl Pulls {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -639,10 +619,7 @@ impl Pulls {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -671,26 +648,20 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::CommitDataType>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/{}/commits?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&pull_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -748,26 +719,20 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::DiffEntry>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/{}/files?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&pull_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -856,10 +821,7 @@ impl Pulls {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -888,26 +850,20 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<crate::types::PullRequestReview> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/{}/requested_reviewers?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&pull_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -943,10 +899,7 @@ impl Pulls {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -980,10 +933,7 @@ impl Pulls {
         );
 
         self.client
-            .delete(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .delete(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1012,26 +962,20 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::PullRequestReviewData>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/{}/reviews?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&pull_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1100,10 +1044,7 @@ impl Pulls {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1174,10 +1115,7 @@ impl Pulls {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1242,27 +1180,21 @@ impl Pulls {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::ReviewComment>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/{}/reviews/{}/comments?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&pull_number.to_string()),
             crate::progenitor_support::encode_path(&review_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1330,10 +1262,7 @@ impl Pulls {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1370,10 +1299,7 @@ impl Pulls {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1407,10 +1333,7 @@ impl Pulls {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
