@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct SecretScanning {
-    client: Client,
+    pub client: Client,
 }
 
 impl SecretScanning {
@@ -41,29 +41,25 @@ impl SecretScanning {
         page: i64,
         per_page: i64,
     ) -> Result<Vec<crate::types::SecretScanningAlert>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
         if !secret_type.is_empty() {
-            query_args.push(format!("secret_type={}", secret_type));
+            query_args.push(("secret_type".to_string(), secret_type.to_string()));
         }
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/secret-scanning/alerts?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -89,23 +85,19 @@ impl SecretScanning {
         state: crate::types::SecretScanningAlertState,
         secret_type: &str,
     ) -> Result<Vec<crate::types::SecretScanningAlert>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !secret_type.is_empty() {
-            query_args.push(format!("secret_type={}", secret_type));
+            query_args.push(("secret_type".to_string(), secret_type.to_string()));
         }
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/secret-scanning/alerts?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -176,10 +168,7 @@ impl SecretScanning {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
