@@ -116,16 +116,40 @@ pub mod date_time_format {
     {
         let s: Option<String> = Option::deserialize(deserializer)?;
         if let Some(mut s) = s {
-            match Utc.datetime_from_str(&s, "%+") {
+            // This is standard.
+            match serde_json::from_str::<DateTime<Utc>>(&format!("\"{}\"", s)) {
                 Ok(t) => Ok(Some(t)),
                 Err(_) => {
-                    s = format!("{}+00:00", s);
-                    // Try both ways to parse the date.
-                    match Utc.datetime_from_str(&s, FORMAT) {
-                        Ok(r) => Ok(Some(r)),
-                        Err(_) => match Utc.datetime_from_str(&s, "%+") {
-                            Ok(d) => Ok(Some(d)),
-                            Err(e) => Err(serde::de::Error::custom(e.to_string())),
+                    // This is google calendar.
+                    match Utc.datetime_from_str(&s, "%Y-%m-%dT%H:%M:%S%.3fZ") {
+                        Ok(t) => Ok(Some(t)),
+                        Err(_) => match Utc.datetime_from_str(&s, FORMAT) {
+                            Ok(t) => Ok(Some(t)),
+                            Err(_) => match Utc.datetime_from_str(&s, "%+") {
+                                Ok(t) => Ok(Some(t)),
+                                Err(_) => match chrono::NaiveDate::parse_from_str(&s, "%Y-%m-%d") {
+                                    Ok(d) => Ok(Some(DateTime::<Utc>::from_utc(
+                                        chrono::NaiveDateTime::new(
+                                            d,
+                                            chrono::NaiveTime::from_hms(0, 0, 0),
+                                        ),
+                                        Utc,
+                                    ))),
+                                    Err(_) => {
+                                        s = format!("{}+00:00", s);
+                                        match Utc.datetime_from_str(&s, FORMAT) {
+                                            Ok(r) => Ok(Some(r)),
+                                            Err(_) => match Utc.datetime_from_str(&s, "%+") {
+                                                Ok(d) => Ok(Some(d)),
+                                                Err(e) => Err(serde::de::Error::custom(format!(
+                                                    "deserializing {} as DateTime<Utc> failed: {}",
+                                                    s, e
+                                                ))),
+                                            },
+                                        }
+                                    }
+                                },
+                            },
                         },
                     }
                 }
@@ -548,3 +572,30 @@ pub fn zero_f32(num: &f32) -> bool {
 pub fn zero_f64(num: &f64) -> bool {
     *num == 0.0
 }
+
+pub mod google_calendar_date_time_format {
+    use chrono::{DateTime, Utc};
+    use serde::{self, Serializer};
+
+    // Google Calendar doesn't accept actual normal date formats they want this.
+    const FORMAT: &str = "%Y-%m-%dT%H:%M:%S%.3fZ";
+
+    // The signature of a serialize_with function must follow the pattern:
+    //
+    //    fn serialize<S>(&T, S) -> Result<S::Ok, S::Error>
+    //    where
+    //        S: Serializer
+    //
+    // although it may also be generic over the input types T.
+    pub fn serialize<S>(date: &Option<DateTime<Utc>>, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        if date.is_some() {
+            let s = format!("{}", date.unwrap().format(FORMAT));
+            return serializer.serialize_str(&s);
+        }
+
+        serializer.serialize_none()
+    }
+}
